@@ -11,7 +11,7 @@ class BaseMetaclass(type):
     """Metaclass for models."""
 
     def __new__(cls, class_name, bases, attr):
-
+        """Rewriting defined fields."""
         fields = {}
         for name, field in attr.items():
             if isinstance(field, BaseField):
@@ -26,30 +26,29 @@ class PreBase(object):
 
     """Base class for all models.
 
-    For compatibility reasons (Python 2 and 3) it is called `PreBase`
-    and you MUST in fact use class called `Base` defined after this class.
+    For compatibility reasons (Python 2 and 3) it is called `PreBase` and
+    models MUST in fact inherit from class `Base`, otherwise it won't work.
 
     """
 
     def __init__(self, **kwargs):
+        """Init."""
         self.populate(**kwargs)
 
     def populate(self, **kw):
-        """Populate values to fields."""
+        """Populate values to fields. Skip non-existing."""
         for name, value in kw.items():
-            # Check for field, if absent, skip this values.
             try:
                 field = self._fields[name]
             except KeyError:
                 continue
 
-            # Let field decide in what format this value should be in.
             parsed_value = field.parse_value(value)
 
             setattr(self, name, parsed_value)
 
     def get_field(self, name):
-        """Get field associated with given name/attribute."""
+        """Get field associated with given attribute."""
         return self._fields[name]
 
     def validate(self):
@@ -59,19 +58,21 @@ class PreBase(object):
             field.validate(name, value)
 
     def __iter__(self):
+        """Iterate through fields and values."""
         for name, field in self._fields.items():
             value = getattr(self, name)
             yield name, value
 
     def to_struct(self):
-        """Cast model to structure. Shortcut method."""
+        """Cast model to structure."""
         return parsers.to_struct(self)
 
     def to_json_schema(self):
-        """Cast model to JSON schema. Shortcut method."""
+        """Cast model to JSON schema."""
         return parsers.to_json_schema(self)
 
     def __repr__(self):
+        """Get representation of model."""
         try:
             txt = six.text_type(self)
         except TypeError:
@@ -79,6 +80,7 @@ class PreBase(object):
         return '<{}: {}>'.format(self.__class__.__name__, txt)
 
     def __str__(self):
+        """Get informal representation."""
         return '{} object'.format(self.__class__.__name__)
 
 # Actual base for models.
